==> org.eclipse.osee.server.p2-0.26.0-SNAPSHOT.zip: org/eclipse/osee/ats/api/workdef/IAtsWidgetDefinition.java <==
/*******************************************************************************
 * Copyright (c) 2013 Boeing.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     Boeing - initial API and implementation
 *******************************************************************************/
package org.eclipse.osee.ats.api.workdef;

import java.util.Map;
import org.eclipse.osee.framework.core.data.AttributeTypeToken;

/**
 * @author Donald G. Dunne
 */
public interface IAtsWidgetDefinition extends IAtsLayoutItem {

   @Override
   public String getName();

   public String getToolTip();

   public String getDescription();

   public String getDefaultValue();

   public boolean is(WidgetOption widgetOption);

   public IAtsWidgetOptionHandler getOptions();

   public void setConstraint(double min, double max);

   public Double getMax();

   public Double getMin();

   public void set(WidgetOption widgetOption);

   public String getXWidgetName();

   public void setXWidgetName(String xWidgetName);

   public int getHeight();

   public void setHeight(int height);

   @Override
   public String toString();

   public AttributeTypeToken getAttributeType();

   public void addParameter(String key, Object obj);

   public Object getParameter(String key);

   Map<String, Object> getParameters();

}

==> org.eclipse.osee.server.p2-1.0.0-SNAPSHOT.zip: org/eclipse/osee/ats/api/workdef/IAtsWidgetDefinition.java <==
/*********************************************************************
 * Copyright (c) 2013 Boeing
 *
 * This program and the accompanying materials are made
 * available under the terms of the Eclipse Public License 2.0
 * which is available at https://www.eclipse.org/legal/epl-2.0/
 *
 * SPDX-License-Identifier: EPL-2.0
 *
 * Contributors:
 *     Boeing - initial API and implementation
 **********************************************************************/

package org.eclipse.osee.ats.api.workdef;

import java.util.Map;
import org.eclipse.osee.framework.core.data.AttributeTypeToken;
import org.eclipse.osee.framework.core.data.RelationTypeSide;

/**
 * @author Donald G. Dunne
 */
public interface IAtsWidgetDefinition extends IAtsLayoutItem {

   @Override
   public String getName();

   public String getToolTip();

   public String getDescription();

   public String getDefaultValue();

   public boolean is(WidgetOption widgetOption);

   public IAtsWidgetOptionHandler getOptions();

   public void setConstraint(double min, double max);

   public Double getMax();

   public Double getMin();

   public void set(WidgetOption widgetOption);

   public String getXWidgetName();

   public void setXWidgetName(String xWidgetName);

   public int getHeight();

   public void setHeight(int height);

   @Override
   public String toString();

   public AttributeTypeToken getAttributeType();

   public void addParameter(String key, Object obj);

   public Object getParameter(String key);

   Map<String, Object> getParameters();

   RelationTypeSide getRelationTypeSide();

}
